@@ -145,5 +145,5 @@ class SQLKV(KV[T], Generic[T]):
     
   
   def prefixed(self, prefix: str):
-    new_prefix = self.prefix_.rstrip('/') + '/' + prefix.strip('/')
+    new_prefix = self.prefix_.rstrip('/') + '/' + prefix.lstrip('/')
     return replace(self, prefix_=new_prefix.lstrip('/'))
\ No newline at end of file
